@@ -11,8 +11,10 @@ Available subpackages
 ---------------------
     utils
         Basic functions useful for fixed income applications.
+    bonds
+        Functions useful for analyzing fixed rate bonds.
 """
 
-__all__ = ['utils']
+__all__ = ['utils', 'bonds']
 
 from fixedincome import *
